@@ -1,10 +1,10 @@
 package Net::DNS::RR::RRSIG;
 
 #
-# $Id: RRSIG.pm 1302 2015-01-23 11:07:41Z willem $
+# $Id: RRSIG.pm 1307 2015-02-02 09:30:57Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1302 $)[1];
+$VERSION = (qw$LastChangedRevision: 1307 $)[1];
 
 
 use strict;
@@ -109,15 +109,14 @@ sub parse_rdata {			## populate RR from rdata in argument list
 
 	my %algbyval = reverse @algbyname;
 
-	my @algbynum = map { ( $_, 0 + $_ ) } keys %algbyval;	# accept algorithm number
-
-	my %algbyname = map { s /[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
+	my @algbynum = map { ( $_, 0 + $_ ) } ( 1 .. 250, keys %algbyval );
 
+	my %algbyname = map { s/[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
 
 	sub algbyname {
 		my $name = shift;
 		my $key	 = uc $name;				# synthetic key
-		$key =~ s /[^A-Z0-9]//g;			# strip non-alphanumerics
+		$key =~ s/[^A-Z0-9]//g;				# strip non-alphanumerics
 		return $algbyname{$key} || croak "unknown algorithm $name";
 	}
 
@@ -581,7 +580,7 @@ sub _CreateSig {
 
 	eval {
 		my $class = $SEC{$algorithm} || die "algorithm $algorithm not supported";
-		$self->sigbin( $class->generate(@_) );
+		$self->sigbin( $class->sign(@_) );
 	} || croak 'signature generation failed', $@ ? "\n\t$@" : '';
 }
 
@@ -876,10 +875,10 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::SEC>,
 RFC4034, RFC6840, RFC3755,
-L<Crypt::OpenSSL::DSA>,
-L<Crypt::OpenSSL::EC>,
-L<Crypt::OpenSSL::ECDSA>,
-L<Crypt::OpenSSL::RSA>
+L<Net::DNS::SEC::DSA>,
+L<Net::DNS::SEC::ECCGOST>,
+L<Net::DNS::SEC::ECDSA>,
+L<Net::DNS::SEC::RSA>
 
 L<Algorithm Numbers|http://www.iana.org/assignments/dns-sec-alg-numbers>
 
